#!/usr/bin/env python3
#exonware/xwformats/src/xwformats.py
"""
Convenience import alias for xwformats.
Allows: import xwformats
Instead of: import exonware.xwformats
"""

from exonware.xwformats import *
